@@ -16,8 +16,6 @@ package hugio
 import (
 	"fmt"
 	"io"
-	"io/ioutil"
-	"os"
 	"path/filepath"
 
 	"github.com/spf13/afero"
@@ -53,7 +51,7 @@ func CopyFile(fs afero.Fs, from, to string) error {
 
 // CopyDir copies a directory.
 func CopyDir(fs afero.Fs, from, to string, shouldCopy func(filename string) bool) error {
-	fi, err := os.Stat(from)
+	fi, err := fs.Stat(from)
 	if err != nil {
 		return err
 	}
@@ -67,7 +65,7 @@ func CopyDir(fs afero.Fs, from, to string, shouldCopy func(filename string) bool
 		return err
 	}
 
-	entries, _ := ioutil.ReadDir(from)
+	entries, _ := afero.ReadDir(fs, from)
 	for _, entry := range entries {
 		fromFilename := filepath.Join(from, entry.Name())
 		toFilename := filepath.Join(to, entry.Name())
