@@ -80,6 +80,10 @@ type Twitter struct {
 type Vimeo struct {
 	Service `mapstructure:",squash"`
 
+	// When set to true, the Vimeo player will be blocked from tracking any session data,
+	// including all cookies and stats.
+	EnableDNT bool
+
 	// If simple mode is enabled, only a thumbnail is fetched from i.vimeocdn.com and
 	// shown with a play button overlaid. If a user clicks the button, he/she will
 	// be taken to the video page on vimeo.com in a new browser tab.
