@@ -65,6 +65,7 @@ type Deployer struct {
 	force         bool             // true forces upload of all files
 	invalidateCDN bool             // true enables invalidate CDN cache (if possible)
 	maxDeletes    int              // caps the # of files to delete; -1 to disable
+	workers       int              // The number of workers to transfer files
 
 	// For tests...
 	summary deploySummary // summary of latest Deploy results
@@ -118,6 +119,7 @@ func New(cfg config.Provider, localFs afero.Fs) (*Deployer, error) {
 		force:         cfg.GetBool("force"),
 		invalidateCDN: cfg.GetBool("invalidateCDN"),
 		maxDeletes:    cfg.GetInt("maxDeletes"),
+		workers:       cfg.GetInt("workers"),
 	}, nil
 }
 
@@ -189,7 +191,10 @@ func (d *Deployer) Deploy(ctx context.Context) error {
 	// Apply the changes in parallel, using an inverted worker
 	// pool (https://www.youtube.com/watch?v=5zXAHh5tJqQ&t=26m58s).
 	// sem prevents more than nParallel concurrent goroutines.
-	const nParallel = 10
+	if d.workers <= 0 {
+		d.workers = 10
+	}
+	nParallel := d.workers
 	var errs []error
 	var errMu sync.Mutex // protects errs
 
