@@ -127,7 +127,7 @@ func decodeConfig(cfg config.Provider) (deployConfig, error) {
 		return dcfg, err
 	}
 	for _, tgt := range dcfg.Targets {
-		if tgt == nil {
+		if *tgt == (target{}) {
 			return dcfg, errors.New("empty deployment target")
 		}
 		if err := tgt.parseIncludeExclude(); err != nil {
@@ -136,7 +136,7 @@ func decodeConfig(cfg config.Provider) (deployConfig, error) {
 	}
 	var err error
 	for _, m := range dcfg.Matchers {
-		if m == nil {
+		if *m == (matcher{}) {
 			return dcfg, errors.New("empty deployment matcher")
 		}
 		m.re, err = regexp.Compile(m.Pattern)
