@@ -458,10 +458,3 @@ func BenchmarkUniqueStrings(b *testing.B) {
 		}
 	})
 }
-
-func TestHashString(t *testing.T) {
-	c := qt.New(t)
-
-	c.Assert(HashString("a", "b"), qt.Equals, "2712570657419664240")
-	c.Assert(HashString("ab"), qt.Equals, "590647783936702392")
-}
