@@ -21,6 +21,7 @@ import (
 
 	"errors"
 
+	"github.com/gohugoio/hugo/common/herrors"
 	"github.com/spf13/afero"
 )
 
@@ -161,7 +162,7 @@ func (fs *SliceFs) pickFirst(name string) (os.FileInfo, int, error) {
 			return fi, i, nil
 		}
 
-		if !os.IsNotExist(err) {
+		if !herrors.IsNotExist(err) {
 			// Real error
 			return nil, -1, err
 		}
@@ -175,7 +176,7 @@ func (fs *SliceFs) readDirs(name string, startIdx, count int) ([]os.FileInfo, er
 	collect := func(lfs *FileMeta) ([]os.FileInfo, error) {
 		d, err := lfs.Fs.Open(name)
 		if err != nil {
-			if !os.IsNotExist(err) {
+			if !herrors.IsNotExist(err) {
 				return nil, err
 			}
 			return nil, nil
