@@ -20,6 +20,7 @@ import (
 	"sort"
 	"strings"
 
+	"github.com/gohugoio/hugo/common/herrors"
 	"github.com/gohugoio/hugo/common/loggers"
 
 	"errors"
@@ -118,7 +119,7 @@ func (w *Walkway) Walk() error {
 	} else {
 		info, _, err := lstatIfPossible(w.fs, w.root)
 		if err != nil {
-			if os.IsNotExist(err) {
+			if herrors.IsNotExist(err) {
 				return nil
 			}
 
@@ -154,7 +155,7 @@ func (w *Walkway) checkErr(filename string, err error) bool {
 		return true
 	}
 
-	if os.IsNotExist(err) {
+	if herrors.IsNotExist(err) {
 		// The file may be removed in process.
 		// This may be a ERROR situation, but it is not possible
 		// to determine as a general case.
