@@ -19,20 +19,19 @@ import (
 	"strings"
 	"testing"
 
+	"github.com/gohugoio/hugo/config"
 	"github.com/gohugoio/hugo/identity"
 
 	qt "github.com/frankban/quicktest"
 	"github.com/gohugoio/hugo/deps"
 	"github.com/gohugoio/hugo/hugofs"
 	"github.com/gohugoio/hugo/tpl"
-
-	"github.com/spf13/viper"
 )
 
 func TestTemplateLookupOrder(t *testing.T) {
 	var (
 		fs  *hugofs.Fs
-		cfg *viper.Viper
+		cfg config.Provider
 		th  testHelper
 	)
 
@@ -457,22 +456,32 @@ complex: 80: 80
 `,
 		)
 	})
+}
 
-	c.Run("Zero argument", func(c *qt.C) {
-		b := newBuilder(c)
+// Issue 7528
+func TestPartialWithZeroedArgs(t *testing.T) {
+	b := newTestSitesBuilder(t)
+	b.WithTemplatesAdded("index.html",
+		` 
+X{{ partial "retval" dict }}X
+X{{ partial "retval" slice }}X
+X{{ partial "retval" "" }}X
+X{{ partial "retval" false }}X
+X{{ partial "retval" 0 }}X
+{{ define "partials/retval" }}
+  {{ return 123 }}
+{{ end }}`)
 
-		b.WithTemplatesAdded(
-			"index.html", `
-Test Partials With Return Values:
-
-add42: fail: {{ partial "add42.tpl" 0 }}
-
-`,
-		)
-
-		e := b.CreateSites().BuildE(BuildCfg{})
-		b.Assert(e, qt.Not(qt.IsNil))
-	})
+	b.WithContentAdded("p.md", ``)
+	b.Build(BuildCfg{})
+	b.AssertFileContent("public/index.html",
+		`
+X123X
+X123X
+X123X
+X123X
+X123X
+`)
 }
 
 func TestPartialCached(t *testing.T) {
@@ -584,6 +593,26 @@ func TestTemplateGoIssues(t *testing.T) {
 		"index.html", `
 {{ $title := "a & b" }}
 <script type="application/ld+json">{"@type":"WebPage","headline":"{{$title}}"}</script>
+
+{{/* Action/commands newlines, from Go 1.16, see https://github.com/golang/go/issues/29770 */}}
+{{ $norway := dict
+	"country" "Norway"
+	"population" "5 millions"
+	"language" "Norwegian"
+	"language_code" "nb"
+	"weather" "freezing cold"
+	"capitol" "Oslo"
+	"largest_city" "Oslo"
+	"currency"  "Norwegian krone"
+	"dialing_code" "+47"
+}}
+
+Population in Norway is {{
+	  $norway.population
+	| lower
+	| upper
+}}
+
 `,
 	)
 
@@ -591,6 +620,7 @@ func TestTemplateGoIssues(t *testing.T) {
 
 	b.AssertFileContent("public/index.html", `
 <script type="application/ld+json">{"@type":"WebPage","headline":"a \u0026 b"}</script>
+Population in Norway is 5 MILLIONS
 
 `)
 }
@@ -725,3 +755,20 @@ This is single main
 `,
 	)
 }
+
+// Issue 9393.
+func TestApplyWithNamespace(t *testing.T) {
+	b := newTestSitesBuilder(t)
+
+	b.WithTemplates(
+		"index.html", `
+{{ $b := slice " a " "     b "   "       c" }}		
+{{ $a := apply $b "strings.Trim" "." " " }}
+a: {{ $a }}
+`,
+	).WithContent("p1.md", "")
+
+	b.Build(BuildCfg{})
+
+	b.AssertFileContent("public/index.html", `a: [a b c]`)
+}
