@@ -41,8 +41,8 @@ func (t *tocTransformer) Transform(n *ast.Document, reader text.Reader, pc parse
 	}
 
 	var (
-		toc         tableofcontents.Root
-		tocHeading  tableofcontents.Heading
+		toc         tableofcontents.Builder
+		tocHeading  = &tableofcontents.Heading{}
 		level       int
 		row         = -1
 		inHeading   bool
@@ -53,10 +53,10 @@ func (t *tocTransformer) Transform(n *ast.Document, reader text.Reader, pc parse
 		s := ast.WalkStatus(ast.WalkContinue)
 		if n.Kind() == ast.KindHeading {
 			if inHeading && !entering {
-				tocHeading.Text = headingText.String()
+				tocHeading.Title = headingText.String()
 				headingText.Reset()
 				toc.AddAt(tocHeading, row, level-1)
-				tocHeading = tableofcontents.Heading{}
+				tocHeading = &tableofcontents.Heading{}
 				inHeading = false
 				return s, nil
 			}
@@ -106,7 +106,7 @@ func (t *tocTransformer) Transform(n *ast.Document, reader text.Reader, pc parse
 		return s, nil
 	})
 
-	pc.Set(tocResultKey, toc)
+	pc.Set(tocResultKey, toc.Build())
 }
 
 type tocExtension struct {
