@@ -14,13 +14,13 @@
 package page
 
 import (
+	"fmt"
 	"path/filepath"
 	"strings"
 
 	"github.com/gohugoio/hugo/common/maps"
 	"github.com/gohugoio/hugo/hugofs/glob"
 	"github.com/mitchellh/mapstructure"
-	"github.com/pkg/errors"
 )
 
 // A PageMatcher can be used to match a Page with Glob patterns.
@@ -132,7 +132,7 @@ func DecodePageMatcher(m any, v *PageMatcher) error {
 			}
 		}
 		if !found {
-			return errors.Errorf("%q did not match a valid Page Kind", v.Kind)
+			return fmt.Errorf("%q did not match a valid Page Kind", v.Kind)
 		}
 	}
 
