@@ -19,7 +19,6 @@ import (
 	"path/filepath"
 	"strings"
 	"testing"
-	"time"
 
 	"github.com/spf13/afero"
 
@@ -189,11 +188,10 @@ func TestResourcesGetMatch(t *testing.T) {
 func BenchmarkResourcesMatch(b *testing.B) {
 	resources := benchResources(b)
 	prefixes := []string{"abc*", "jkl*", "nomatch*", "sub/*"}
-	rnd := rand.New(rand.NewSource(time.Now().Unix()))
 
 	b.RunParallel(func(pb *testing.PB) {
 		for pb.Next() {
-			resources.Match(prefixes[rnd.Intn(len(prefixes))])
+			resources.Match(prefixes[rand.Intn(len(prefixes))])
 		}
 	})
 }
@@ -246,7 +244,7 @@ func BenchmarkAssignMetadata(b *testing.B) {
 	for i := 0; i < b.N; i++ {
 		b.StopTimer()
 		var resources resource.Resources
-		meta := []map[string]interface{}{
+		meta := []map[string]any{
 			{
 				"title": "Foo #:counter",
 				"name":  "Foo Name #:counter",
