@@ -47,9 +47,8 @@ func (t *minifyTransformation) Key() internal.ResourceTransformationKey {
 }
 
 func (t *minifyTransformation) Transform(ctx *resources.ResourceTransformationCtx) error {
-	_ = t.m.Minify(ctx.InMediaType, ctx.To, ctx.From)
 	ctx.AddOutPathIdentifier(".min")
-	return nil
+	return t.m.Minify(ctx.InMediaType, ctx.To, ctx.From)
 }
 
 func (c *Client) Minify(res resources.ResourceTransformer) (resource.Resource, error) {
