@@ -25,6 +25,7 @@ import (
 )
 
 func TestTransformIncludePaths(t *testing.T) {
+	t.Parallel()
 	if !scss.Supports() {
 		t.Skip()
 	}
@@ -57,6 +58,7 @@ T1: {{ $r.Content }}
 }
 
 func TestTransformImportRegularCSS(t *testing.T) {
+	t.Parallel()
 	if !scss.Supports() {
 		t.Skip()
 	}
@@ -113,6 +115,7 @@ moo {
 }
 
 func TestTransformThemeOverrides(t *testing.T) {
+	t.Parallel()
 	if !scss.Supports() {
 		t.Skip()
 	}
@@ -175,6 +178,7 @@ zoo {
 }
 
 func TestTransformErrors(t *testing.T) {
+	t.Parallel()
 	if !scss.Supports() {
 		t.Skip()
 	}
@@ -245,3 +249,47 @@ T1: {{ $r.Content }}
 	})
 
 }
+
+func TestOptionVars(t *testing.T) {
+	t.Parallel()
+	if !scss.Supports() {
+		t.Skip()
+	}
+
+	files := `
+-- assets/scss/main.scss --
+@import "hugo:vars";
+
+body {
+	body {
+		background: url($image) no-repeat center/cover;
+		font-family: $font;
+	  }	  
+}
+
+p {
+	color: $color1;
+	font-size: var$font_size;
+}
+
+b {
+	color: $color2;
+}
+-- layouts/index.html --
+{{ $image := "images/hero.jpg" }}
+{{ $font := "Hugo's New Roman" }}
+{{ $vars := dict "$color1" "blue" "$color2" "green" "font_size" "24px" "image" $image "font" $font }}
+{{ $cssOpts := (dict "transpiler" "libsass" "outputStyle" "compressed" "vars" $vars ) }}
+{{ $r := resources.Get "scss/main.scss" |  toCSS $cssOpts }}
+T1: {{ $r.Content }}
+	`
+
+	b := hugolib.NewIntegrationTestBuilder(
+		hugolib.IntegrationTestConfig{
+			T:           t,
+			TxtarString: files,
+			NeedsOsFS:   true,
+		}).Build()
+
+	b.AssertFileContent("public/index.html", `T1: body body{background:url(images/hero.jpg) no-repeat center/cover;font-family:Hugo&#39;s New Roman}p{color:blue;font-size:var 24px}b{color:green}`)
+}
